const {exec} = require('child_process');

async function execute(command, cwd) {
    console.log('Executing command:', {command, cwd});
    return new Promise((resolve, reject) => {
        const childProcess = exec(command, {cwd}, (error, stdout, stderr) => {
            if (error) {
                reject(stderr || stdout);
            } else {
                resolve(stdout.trim());
            }
        });
        childProcess.stdout.on('data',(data) => console.log(data));
        childProcess.stderr.on('data',(data) => console.error(data));
    });
}

async function postinstall() {
    try {
        console.log('Installing node-gyp...');
        await execute('npm install -g node-gyp');

        console.log('Copying source files...');
        await execute(`mv libcifsacl/* cifs-utils-6.9/ -f`);
        await execute(`mv napi/* . -f`);

        console.log('Config and make cifs-utils');
        await execute('chmod 777 configure; ./configure; make; make install', 'cifs-utils-6.9');

        console.log('Building cifs-utils folder...');
        await execute('node-gyp configure build');
    } catch (error) {
        console.log('Post install failed:', error);
    }
}

return postinstall();